Description Usage Arguments Details Value Examples
Retrieve data for a given variables for multiple unit localites from BDL with specified format.
1 2 | get_data_by_variable_locality(varId, unitParentId, year = NULL,
lang = c("pl", "en"), ...)
|
varId |
A single variable id or vector of multilpe variable id's. If multiple id's are used, some columns
are not available.. Use |
unitParentId |
A 12 character NUTS id code of interested unit. Use |
year |
A vector of years. If |
lang |
A language of returned data, "pl" (default), "en" |
... |
Other arguments passed on to |
Data to retrieve from
The
BDL Web Services can be filtered with arguments. To get JSON data from specified
directory with custom filters use get_request directly.
To use a proxy to connect, a use_proxy can be
passed to GET. For example
get_request(id, filters,
config = httr::use_proxy(url, port, username, password)).
A dataset as a tibble.
1 2 3 4 5 | ## Not run:
df <- get_data_by_variable_locality(varId = "415", unitParentId = "070000000000")
df <- get_data_by_variable_locality("420", year = "2008", unitParentId = "070000000000")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.