Description Usage Arguments Details Value Examples
Generate line plot for one unit/multiple variables or varaible/multiple units
1 2 3 4 |
data_type |
A type of data used for generating plot, "unit"(default), "unit.locality","variable","variable.locality" |
unitId |
A 12 character NUTS unit id or locality 12 character id with 7 characters locality individual id, separated by dash. |
varId |
A vector of variable Id's (data_type equal "unit" or "unit.locality)
or single variable (data_type equal "variable" or "varaible.locality"). Use |
year |
A vector of years. If |
aggregateId |
An aggregate id. Use |
lang |
A language of returned data, "pl" (default), "en" |
unitParentId |
A 12 character NUTS id code of interested unit. (Used only with data_type equal "variable" or "variable.locality")
Use |
unitLevel |
A number from 0 to 6, filters the returned unit by its level. (Used only with data_type equal "variable")
If |
... |
Other arguments passed on to |
Generate quickly ggplot2 plot, using BDL data.
Plot multiple variable values for one unit or one variable value for multiple units.
To use a proxy to connect, a use_proxy can be
passed to GET. For example
get_request(id, filters,
config = httr::use_proxy(url, port, username, password)).
A ggplot2 plot.
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.